/***************************************************************************
 * cfgfiles.h - some (hopefully) generic routines for parsing config files *
 *                           Red Hat Config Library                        *
 * (c) 1999 by Bernhard Rosenkrnzer <bero@redhat.com>                     *
 * $Id: cfgfiles.h,v 1.1.1.1 2000/01/20 21:23:28 brosenkr Exp $                    *
 ***************************************************************************/

#ifndef RHCL_CFGFILES_H
#define RHCL_CFGFILES_H

#include <string.h>
#include <stdio.h>
#include <unistd.h>

#ifdef __cplusplus
extern "C" {
#endif

/** Get a setting in the form of SOMETHING=value from a config file.
 * Example: In a config file saying
 * 	param1=blah
 * 	param2=something
 * rhcl_get_setting(config, "param2") returns "something".
 * 
 * @param from config file (text)
 * @param what what setting to look for
 * @return setting
 */
char *rhcl_get_setting(char const * const from, char const * const what);

/** Replace all occurences of
 * @param what
 * with
 * @param with
 * in
 * @param str
 *
 * @return String with all occurrences replaced.
 */
/* XXX */
#define replace rhcl_replace
char *rhcl_replace(char const * const str, char const * const what, char const * const with);

/** Case-insensitive version of strstr
 * Find the first occurrence of @param haystack in @param needle
 * case insensitive.
 *
 * @return first occurrence
 */
const char *rhcl_strcasestr(const char *haystack, char const * const needle);

/** Remove blanks from beginning and end of line
 * @param line Line you want trimmed
 * @return @param line without blanks at beginning and end
 */
char *rhcl_trim(const char *line);

#ifdef __cplusplus
}
#endif

#endif
